aboutsummaryrefslogtreecommitdiffstats
path: root/sound/avirt.h
diff options
context:
space:
mode:
Diffstat (limited to 'sound/avirt.h')
-rw-r--r--sound/avirt.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/sound/avirt.h b/sound/avirt.h
index 5df84fe..1a5c546 100644
--- a/sound/avirt.h
+++ b/sound/avirt.h
@@ -17,34 +17,34 @@
#define MAX_STREAMS 16
#define MAX_NAME_LEN 80
-#define DINFO(logname, fmt, args...) \
+#define DINFO(logname, fmt, args...) \
snd_printk(KERN_INFO "AVIRT: %s: " fmt "\n", logname, ##args)
-#define DERROR(logname, fmt, args...) \
+#define DERROR(logname, fmt, args...) \
snd_printk(KERN_ERR "AVIRT: %s: " fmt "\n", logname, ##args)
-#define DDEBUG(logname, fmt, args...) \
+#define DDEBUG(logname, fmt, args...) \
snd_printk(KERN_DEBUG "AVIRT: %s: " fmt "\n", logname, ##args)
/**
* AVIRT Audio Path configure function type
* Each Audio Path registers this at avirt_audiopath_register time.
* It is then called by the core once AVIRT has been configured
*/
-typedef int (*avirt_audiopath_configure)(struct snd_card *card,
- struct config_group *stream_group,
- unsigned int stream_count);
+typedef int (*snd_avirt_audiopath_configure)(struct snd_card *card,
+ struct config_group *stream_group,
+ unsigned int stream_count);
/**
* AVIRT Audio Path info
*/
-struct avirt_audiopath {
+struct snd_avirt_audiopath {
const char *uid; /* Unique identifier */
const char *name; /* Pretty name */
unsigned int version[3]; /* Version - Major.Minor.Ext */
const struct snd_pcm_hardware *hw; /* ALSA PCM HW conf */
const struct snd_pcm_ops *pcm_ops; /* ALSA PCM op table */
- avirt_audiopath_configure configure; /* Configure callback function */
+ snd_avirt_audiopath_configure configure; /* Config callback function */
void *context;
};
@@ -52,7 +52,7 @@ struct avirt_audiopath {
/*
* Audio stream configuration
*/
-struct avirt_stream {
+struct snd_avirt_stream {
char name[MAX_NAME_LEN]; /* Stream name */
char map[MAX_NAME_LEN]; /* Stream Audio Path mapping */
unsigned int channels; /* Stream channel count */
@@ -65,58 +65,58 @@ struct avirt_stream {
/**
* AVIRT core info
*/
-struct avirt_coreinfo {
+struct snd_avirt_coreinfo {
unsigned int version[3];
};
/**
* avirt_audiopath_register - register Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be registered
* @core: ALSA virtual driver core info
* @return: 0 on success or error code otherwise
*/
-int avirt_audiopath_register(struct avirt_audiopath *audiopath,
- struct avirt_coreinfo **coreinfo);
+int snd_avirt_audiopath_register(struct snd_avirt_audiopath *audiopath,
+ struct snd_avirt_coreinfo **coreinfo);
/**
* avirt_audiopath_deregister - deregister Audio Path with ALSA virtual driver
* @audiopath: Audio Path to be deregistered
* @return: 0 on success or error code otherwise
*/
-int avirt_audiopath_deregister(struct avirt_audiopath *audiopath);
+int snd_avirt_audiopath_deregister(struct snd_avirt_audiopath *audiopath);
/**
* avirt_audiopath_get - retrieves the Audio Path by it's UID
* @uid: Unique ID for the Audio Path
* @return: Corresponding Audio Path
*/
-struct avirt_audiopath *avirt_audiopath_get(const char *uid);
+struct snd_avirt_audiopath *snd_avirt_audiopath_get(const char *uid);
/**
* avirt_stream_count - get the stream count for the given direction
* @direction: The direction to get the stream count for
* @return: The stream count
*/
-int avirt_stream_count(unsigned int direction);
+int snd_avirt_stream_count(unsigned int direction);
/**
- * avirt_stream_from_config_item - Convert a config_item to an avirt_stream
+ * snd_avirt_stream_from_config_item - Convert config_item to a snd_avirt_stream
* @item: The config_item to convert from
* @return: The item's avirt_stream if successful, NULL otherwise
*/
-static inline struct avirt_stream *
-avirt_stream_from_config_item(struct config_item *item)
+static inline struct snd_avirt_stream *
+ snd_avirt_stream_from_config_item(struct config_item *item)
{
- return item ? container_of(item, struct avirt_stream, item) : NULL;
+ return item ? container_of(item, struct snd_avirt_stream, item) : NULL;
}
/**
* avirt_pcm_period_elapsed - PCM buffer complete callback
* @substream: pointer to ALSA PCM substream
*
* This should be called from a child Audio Path once it has finished processing
* the PCM buffer
*/
-void avirt_pcm_period_elapsed(struct snd_pcm_substream *substream);
+void snd_avirt_pcm_period_elapsed(struct snd_pcm_substream *substream);
#endif // __SOUND_AVIRT_H
@@ -17,34 +17,34 @@
/**
* AVIRT Audio Path configure function type
- * Each Audio Path registers this at avirt_audiopath_register time.
+ * Each Audio Path registers this at snd_avirt_audiopath_register time.
* It is then called by the core once AVIRT has been configured
*/
@@ -65,58 +65,58 @@ struct avirt_stream {
};
/**
- * avirt_audiopath_register - register Audio Path with ALSA virtual driver
+ * snd_avirt_audiopath_register - register Audio Path with AVIRT
* @audiopath: Audio Path to be registered
* @core: ALSA virtual driver core info
@@ -65,58 +65,58 @@ struct avirt_stream {
/**
- * avirt_audiopath_deregister - deregister Audio Path with ALSA virtual driver
+ * snd_avirt_audiopath_deregister - deregister Audio Path with AVIRT
* @audiopath: Audio Path to be deregistered
* @return: 0 on success or error code otherwise
@@ -65,58 +65,58 @@ struct avirt_stream {
/**
- * avirt_audiopath_get - retrieves the Audio Path by it's UID
+ * snd_avirt_audiopath_get - retrieves the Audio Path by it's UID
* @uid: Unique ID for the Audio Path
* @return: Corresponding Audio Path
@@ -65,58 +65,58 @@ struct avirt_stream {
/**
- * avirt_stream_count - get the stream count for the given direction
+ * snd_avirt_stream_count - get the stream count for the given direction
* @direction: The direction to get the stream count for
* @return: The stream count
@@ -65,58 +65,58 @@ struct avirt_stream {
* @item: The config_item to convert from
- * @return: The item's avirt_stream if successful, NULL otherwise
+ * @return: The item's snd_avirt_stream if successful, NULL otherwise
*/
@@ -65,58 +65,58 @@ struct avirt_stream {
}
/**
- * avirt_pcm_period_elapsed - PCM buffer complete callback
+ * snd_avirt_pcm_period_elapsed - PCM buffer complete callback
* @substream: pointer to ALSA PCM substream
*